@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of OpenSesame.
 
@@ -15,15 +17,17 @@ You should have received a copy of the GNU General Public License
 along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from libopensesame import item, exceptions
-import shlex
+__author__ = "Sebastiaan Mathot"
+__license__ = "GPLv3"
+
+from libopensesame import item, exceptions, debug
 import openexp.keyboard
 from random import *
 from math import *
 
 class loop(item.item):
 
-	"""A loop item runs a single other item multiple times, while varying independent variables"""
+	"""A loop item runs a single other item multiple times"""
 
 	def __init__(self, name, experiment, string = None):
 
@@ -40,11 +44,14 @@ class loop(item.item):
 
 		self.cycles = 1
 		self.repeat = 1
+		self.skip = 0
+		self.offset = "no"
 		self.matrix = {}
 		self.order = "random"
 		self.description = "Repeatedly runs another item"
 		self.item_type = "loop"
 		self.item = ""
+		self.break_if = ""
 		item.item.__init__(self, name, experiment, string)
 
 	def from_string(self, string):
@@ -61,7 +68,7 @@ class loop(item.item):
 			self.parse_variable(i)
 
 			# Extract the item to run
-			i = shlex.split(i.strip())
+			i = self.split(i.strip())
 			if len(i) > 0:
 				if i[0] == "run" and len(i) > 1:
 					self.item = i[1]
@@ -87,21 +94,28 @@ class loop(item.item):
 
 		"""
 		Run the loop
+		
+		Exceptions:
+		A runtime_error is raised on an error
 
 		Returns:
-		True on success, False on failure
+		True on success. False is never actually returned, since a runtime_error
+		is raised on failure.
 		"""
+		
+		# Prepare the break if condition
+		if self.break_if != "":
+			self._break_if = self.compile_cond(self.break_if)
+		else:
+			self._break_if = None
 
-		# First generate a list
+		# First generate a list of cycle numbers
 		l = []
-
-		j = 0
-
 		# Walk through all complete repeats
 		whole_repeats = int(self.repeat)
 		for j in range(whole_repeats):
 			for i in range(self.cycles):
-				l.append( (j, i) )
+				l.append(i)
 
 		# Add the leftover repeats
 		partial_repeats = self.repeat - whole_repeats
@@ -109,47 +123,75 @@ class loop(item.item):
 			all_cycles = range(self.cycles)
 			_sample = sample(all_cycles, int(len(all_cycles) * partial_repeats))
 			for i in _sample:
-				l.append( (j, i) )
+				l.append(i)
 
 		# Randomize the list if necessary
 		if self.order == "random":
 			shuffle(l)
-
+			
+		# In sequential order, the offset and the skip are relevant
+		else:			
+			if len(l) < self.skip:
+				raise exceptions.runtime_error("The value of skip is too high in loop item '%s': You cannot skip more cycles than there are." \
+					% self.name)
+			if self.offset == "yes":
+				l = l[self.skip:] + l[:self.skip]
+			else:
+				l = l[self.skip:]
+				
 		# Create a keyboard to flush responses between cycles
 		self._keyboard = openexp.keyboard.keyboard(self.experiment)
 
-		# Walk through the list
-		for j, i in l:
-			if self.item in self.experiment.items:
-
-				# Set the variables from the matrix
-				if i in self.matrix:
-					for var in self.matrix[i]:
-						val = self.matrix[i][var]
-
-						# By starting with an "=" sign, users can incorporate a Python
-						# statement, for example to call functions from the random or
-						# math module
-						if type(val) == str and len(val) > 2 and val[0] == "=":
-							code = "%s" % self.eval_text(val[1:], soft_ignore = True, quote_str = True)
-							if self.experiment.debug:
-								print "loop.run(): evaluating '%s'" % code
-							try:
-								val = eval(code)
-							except Exception as e:
-								raise exceptions.runtime_error("Failed to evaluate '%s' in loop item '%s': %s" % (code, self.name, e))
-
-						self.experiment.set(var, val)
-
-				if eval("self.experiment.items[\"%s\"].prepare()" % self.item):
-					exec("self.experiment.items[\"%s\"].run()" % self.item)
-				else:
-					raise exceptions.runtime_error("Failed to prepare item '%s', which is called by loop item '%s'" % (self.item, self.name))
-
-			else:
-				raise exceptions.runtime_error("Could not find item '%s', which is called by loop item '%s'" % (self.item, self.name))
-
+		# Make sure the item to run exists		
+		if self.item not in self.experiment.items:
+			raise exceptions.runtime_error( \
+				"Could not find item '%s', which is called by loop item '%s'" \
+				% (self.item, self.name))			
+				
+		# And run!
+		_item = self.experiment.items[self.item]						
+		while len(l) > 0:
+			cycle = l.pop(0)
+			self.apply_cycle(cycle)
+			if self._break_if != None and eval(self._break_if):
+				break
+			self.experiment.set('repeat_cycle', 0)
+			_item.prepare()
+			_item.run()
+			if self.experiment.get('repeat_cycle'):
+				debug.msg('repeating cycle %d' % cycle)
+				l.append(cycle)
+				if self.order == 'random':
+					shuffle(l)
 		return True
+							
+	def apply_cycle(self, cycle):
+	
+		"""
+		Set all the loop variables according to the cycle
+		
+		Arguments:
+		cycle -- the cycle nr
+		"""
+		
+		# If the cycle is not defined, we don't have to do anything
+		if cycle not in self.matrix:
+			return			
+		# Otherwise apply all variables from the cycle
+		for var in self.matrix[cycle]:
+			val = self.matrix[cycle][var]
+			# By starting with an "=" sign, users can incorporate a
+			# Python statement, for example to call functions from
+			# the random or math module
+			if type(val) == unicode and len(val) > 1 and val[0] == "=":
+				try:
+					val = eval(val[1:])
+				except Exception as e:
+					raise exceptions.runtime_error( \
+						"Failed to evaluate '%s' in loop item '%s': %s" \
+						% (val[1:], self.name, e))
+			# Set it!
+			self.experiment.set(var, val)												
 
 	def to_string(self):
 
@@ -182,7 +224,7 @@ class loop(item.item):
 			for var in self.matrix[i]:
 				if var not in var_list:
 					var_list[var] = []
-				var_list[var].append(str(self.matrix[i][var]))
+				var_list[var].append(self.unistr(self.matrix[i][var]))
 		for var in var_list:
 			l.append( (var, "[" + ", ".join(var_list[var]) + "]"))
 		return l
