@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of OpenSesame.
 
@@ -15,6 +17,9 @@ You should have received a copy of the GNU General Public License
 along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+__author__ = "Sebastiaan Mathot"
+__license__ = "GPLv3"
+
 from libopensesame import item, exceptions, generic_response
 import openexp.mouse
 import openexp.exceptions
@@ -43,6 +48,7 @@ class mouse_response(item.item, generic_response.generic_response):
 		self.description = "Collects mouse responses"
 		self.auto_response = 1
 		self.duration = "mouseclick"
+		self.process_feedback = True				
 
 		self.resp_codes = {}
 		self.resp_codes[None] = "timeout"
