@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of OpenSesame.
 
@@ -53,7 +55,7 @@ def plugin_folders(only_existing=True):
 			l.append(path)
 									
 	elif os.name == "nt":
-		path = os.path.join(os.environ["USERPROFILE"], ".opensesame", "plugins")
+		path = os.path.join(os.environ["APPDATA"], ".opensesame", "plugins")
 		if not only_existing or os.path.exists(path):
 			l.append(path)		
 			
@@ -83,11 +85,8 @@ def plugin_disabled(plugin):
 	True if the plugin has been disabled, False otherwise
 	"""
 
-	try:
-		from libqtopensesame import config
-		return plugin in config.get_config("disabled_plugins").split(";")
-	except:
-		return False
+	from libqtopensesame.misc import config
+	return plugin in config.get_config("disabled_plugins").split(";")
 	
 def plugin_property(plugin, _property, default=0):
 
@@ -144,7 +143,8 @@ def list_plugins(filter_disabled=True):
 	
 	global _list	
 	if _list != None:
-		return [plugin for plugin in _list if not (filter_disabled and plugin_disabled(plugin))]
+		return [plugin for plugin in _list if not (filter_disabled and \
+			plugin_disabled(plugin))]
 	
 	plugins = []
 	for folder in plugin_folders():
@@ -157,7 +157,8 @@ def list_plugins(filter_disabled=True):
 	# Sort (inversely) by priority
 	plugins.sort(key=lambda p: -p[1])
 	_list = [plugin[0] for plugin in plugins]
-	return [plugin for plugin in _list if not (filter_disabled and plugin_disabled(plugin))]
+	return [plugin for plugin in _list if not (filter_disabled and \
+		plugin_disabled(plugin))]
 	
 def plugin_folder(plugin):
 	
@@ -177,6 +178,7 @@ def plugin_folder(plugin):
 		return _folders[plugin]	
 	
 	for folder in plugin_folders():
+		plugin = str(plugin)
 		if os.path.exists(os.path.join(folder, plugin, "%s.py" % plugin)):
 			f = os.path.join(folder, plugin)
 			_folders[plugin] = f
@@ -222,6 +224,7 @@ def import_plugin(plugin):
 	"""
 	
 	import imp
+	plugin = str(plugin)
 	path = os.path.join(plugin_folder(plugin), "%s.py" % plugin)
 	return imp.load_source(plugin, path)
 	
@@ -244,7 +247,8 @@ def load_plugin(plugin, item_name, experiment, string, prefix = ""):
 	"""
 
 	mod = import_plugin(plugin)
-	cmd = "mod.%(prefix)s%(plugin)s(item_name, experiment, string)" % {"plugin" : plugin, "prefix" : prefix}
+	cmd = "mod.%(prefix)s%(plugin)s(item_name, experiment, string)" % \
+		{"plugin" : plugin, "prefix" : prefix}
 	item = eval(cmd)
 	return item
 	
