@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of OpenSesame.
 
@@ -17,7 +19,6 @@ along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 
 from libopensesame import item, exceptions
 import openexp.keyboard
-import shlex
 
 class sequence(item.item):
 
@@ -57,7 +58,7 @@ class sequence(item.item):
 		for item, cond in self._items:		
 			if eval(cond):	
 				self.experiment.items[item].run()
-		return True							
+		return True				
 		
 	def parse_run(self, i):
 	
@@ -88,7 +89,7 @@ class sequence(item.item):
 	
 		for i in string.split("\n"):
 			self.parse_variable(i)
-			i = shlex.split(i.strip())
+			i = self.split(i.strip())
 			if len(i) > 0:
 				if i[0] == "run" and len(i) > 1:				
 					self.items.append(self.parse_run(i))			
@@ -134,7 +135,7 @@ class sequence(item.item):
 		A definition string
 		"""
 	
-		s = item.item.to_string(self, "sequence")
+		s = item.item.to_string(self, self.item_type)
 		for _item, cond in self.items:
 			s += "\trun %s \"%s\"\n" % (_item, cond)
 		return s			
