@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of openexp.
 
@@ -38,7 +40,7 @@ class opengl(openexp._canvas.legacy.legacy):
 	
 	settings = None
 
-	def __init__(self, experiment, bgcolor = None, fgcolor = None):
+	def __init__(self, experiment, bgcolor=None, fgcolor=None, auto_prepare=True):
 
 		self.experiment = experiment
 		
@@ -83,13 +85,13 @@ class opengl(openexp._canvas.legacy.legacy):
 
 		"""see openexp._canvas.legacy"""
 		
-		return self.experiment.resolution[0] / 2
+		return self.experiment.get('width') / 2
 
 	def ycenter(self):
 
 		"""see openexp._canvas.legacy"""
 		
-		return self.experiment.resolution[1] / 2
+		return self.experiment.get('height') / 2
 
 	def show(self):
 
@@ -162,12 +164,6 @@ class opengl(openexp._canvas.legacy.legacy):
 		self.showables.append((libopengl.LowImage(surface),
 				       (x-r1,y-r1)))
 
-	def circle(self, x, y, r, fill = False, color = None):
-
-		"""see openexp._canvas.legacy"""
-		
-		self.ellipse(x - r, y - r, 2 * r, 2 * r, fill=fill, color=color)
-
 	def line(self, sx, sy, ex, ey, color = None):
 
 		"""see openexp._canvas.legacy"""
@@ -302,6 +298,14 @@ class opengl(openexp._canvas.legacy.legacy):
 
 		self.showables.append((libopengl.LowImage(surface),
 				       loc))
+				       
+	def polygon(self, vertices, fill=False, color=None):
+		
+		"""see openexp._canvas.legacy"""
+				
+		# TODO
+		raise openexp.exceptions.canvas_error( \
+			"openexp._canvas.opengl.polygon() not implemented")
 
 	def text_size(self, text):
 
@@ -421,7 +425,7 @@ def init_display(experiment):
 	mode = pygame.HWSURFACE | pygame.DOUBLEBUF | pygame.OPENGL
 	if experiment.fullscreen:
 		mode = mode | pygame.FULLSCREEN
-	if pygame.display.mode_ok(experiment.resolution, mode):
+	if pygame.display.mode_ok(experiment.resolution(), mode):
 		print "video.opengl.init_display(): video mode ok"
 	else:
 		print "video.opengl.init_display(): warning: video mode not ok"
@@ -438,13 +442,16 @@ def init_display(experiment):
 	os.environ["LIBGL_SYNC_REFRESH"] = val
 
 	# Create the window and the surface
-	experiment.window = pygame.display.set_mode(experiment.resolution, mode)
+	experiment.window = pygame.display.set_mode(experiment.resolution(), mode)
 	pygame.display.set_caption(experiment.title)
 	pygame.mouse.set_visible(False)
 	experiment.surface = pygame.display.get_surface()
 
 	# Set the time function to use pygame
 	experiment._time_func = pygame.time.get_ticks
+	experiment._sleep_func = pygame.time.delay
+	experiment.time = experiment._time_func
+	experiment.sleep = experiment._sleep_func	
 
 	# Create a font, falling back to the default font
 	experiment.font = pygame.font.Font(experiment.resource("%s.ttf" % experiment.font_family), experiment.font_size)
