@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of openexp.
 
@@ -28,7 +30,7 @@ class legacy:
 	it back. The sampler offers a number of basic operations, such as pitch,
 	panning, and fade in.
 	"""
-	
+
 
 	# The settings variable is used by the GUI to provide a list of back-end
 	# settings
@@ -38,7 +40,7 @@ class legacy:
 			"description" : "Size of the sound buffer (increase if playback is choppy)",
 			"default" : 1024
 			},
-		"sampling_frequency" : {
+		"sound_freq" : {
 			"name" : "Sampling frequency",
 			"description" : "Determines the sampling rate",
 			"default" : 48000
@@ -54,122 +56,159 @@ class legacy:
 			"default" : 2
 			},
 		}
-		
+
 	def __init__(self, experiment, src):
-	
-		"""<DOC>		
-		Initialize the sampler with a specified file
-		
+
+		"""<DOC>
+		Initializes the sampler with a specified file.
+
 		Arguments:
-		experiment -- An instance of libopensesame.experiment.experiment
-		src -- A path to a .wav or .ogg file
-		</DOC>"""		
+		experiment -- An instance of libopensesame.experiment.experiment.
+		src -- A path to a .wav or .ogg file.
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		</DOC>"""
+
 		if src != None:
 			if not os.path.exists(src):
 				raise openexp.exceptions.sample_error("openexp._sampler.legacy.__init__() the file '%s' does not exist" % src)
-		
+
 			if os.path.splitext(src)[1].lower() not in (".ogg", ".wav"):
-				raise openexp.exceptions.sample_error("openexp._sampler.legacy.__init__() the file '%s' is not an .ogg or .wav file" % src)			
-	
+				raise openexp.exceptions.sample_error("openexp._sampler.legacy.__init__() the file '%s' is not an .ogg or .wav file" % src)
+
 			self.sound = pygame.mixer.Sound(src)
-			
+
 		self.experiment = experiment
 		self._stop_after = 0
 		self._fade_in = 0
-		self._volume = 1.0				
-		
+		self._volume = 1.0
+
 	def stop_after(self, ms):
-	
+
 		"""<DOC>
-		Specify a duration after which the sampler stops playing
-		
+		Specifies a duration after which the sampler stops playing.
+
 		Arguments:
-		ms -- A duration in milliseconds
+		ms -- An integer value specifying the duration in milliseconds.
+		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.stop_after(100)		
 		</DOC>"""
-	
+
 		if type(ms) != int or ms < 0:
 			raise openexp.exceptions.sample_error("openexp._sampler.legacy.stop_after() requires a positive integer")
-		
+
 		self._stop_after = ms
 
 	def fade_in(self, ms):
-	
+
 		"""<DOC>
-		Set the fade-in time in milliseconds
-		
+		Sets the fade-in time in milliseconds.
+
 		Arguments:
-		ms - A duration in milliseconds
-		</DOC>"""	
-	
+		ms -- An integer value specifying the duration in milliseconds.
+		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.fade_in(100)		
+		</DOC>"""
+
 		if type(ms) != int or ms < 0:
 			raise openexp.exceptions.sample_error("openexp._sampler.legacy.fade_in() requires a positive integer")
-		
+
 		self._fade_in = ms
-		
+
 	def volume(self, vol):
-	
+
 		"""<DOC>
-		Set the volume
-		
+		Sets the volume.
+
 		Arguments:
 		vol -- A volume between 0.0 and 1.0
+		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.volume(0.5)
 		</DOC>"""
-	
+
 		if type(vol) not in (int, float) or vol < 0 or vol > 1:
 			raise openexp.exceptions.sample_error("openexp._sampler.legacy.volume() requires a number between 0.0 and 1.0")
-	
+
 		self._volume = vol
 		self.sound.set_volume(vol)
-		
+
 	def pitch(self, p):
-		
+
 		"""<DOC>
-		Set the relative pitch of the sample
-		
+		Sets the relative pitch of the sample.
+
 		Arguments:
-		p -- The pitch. p > 1.0 slows the sample down, p < 1.0 speeds the sample up
-		</DOC>"""
+		p -- The pitch. p > 1.0 slows the sample down, p < 1.0 speeds #
+				the sample up.
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.pitch(2.0)
+		</DOC>"""
+
 		if type(p) not in (int, float) or p <= 0:
-			raise openexp.exceptions.sample_error("openexp._sampler.legacy.pitch() requires a positive number")		
-			
+			raise openexp.exceptions.sample_error("openexp._sampler.legacy.pitch() requires a positive number")
+
 		if p == 1:
 			return
-		
+
 		buf = pygame.sndarray.array(self.sound)
 		_buf = []
-		
+
 		for i in range(int(float(len(buf)) / p)):
 			_buf.append(buf[int(float(i) * p)])
 
 		self.sound = pygame.sndarray.make_sound(numpy.array(_buf, dtype="int16"))
-		
+
 	def pan(self, p):
-	
+
 		"""<DOC>
-		Sets the panning of the sample. The volume of the "unpanned" channel
-		decreases, the volume of the other channel remains the same. To fully
-		mute one channel specify "left" (mutes right, pans to left) or "right"
-		(mutes left, pans to right"). 
-		
+		Sets the panning of the sample. The volume of the "unpanned" channel #
+		decreases, the volume of the other channel remains the same. To fully #
+		mute one channel specify "left" (mutes right, pans to left) or "right" #
+		(mutes left, pans to right").
+
 		Arguments:
-		p -- Panning. A float (p < 0 = to left, p > 0 = to right) or string ("left" or "right")
-		</DOC>"""
+		p -- Panning. A float (p < 0 = to left, p > 0 = to right) or string #
+			 ("left" or "right").
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.pan('left')
+		</DOC>"""
+
 		if type(p) not in (int, float) and p not in ("left", "right"):
-			raise openexp.exceptions.sample_error("openexp._sampler.legacy.pan() requires a number or 'left', 'right'")		
-			
+			raise openexp.exceptions.sample_error("openexp._sampler.legacy.pan() requires a number or 'left', 'right'")
+
 		if p == 0:
 			return
-		
+
 		buf = pygame.sndarray.array(self.sound)
-		
+
 		for i in range(len(buf)):
-		
+
 			l = buf[i][0]
 			r = buf[i][1]
-		
+
 			if p == "left":
 				r = 0
 			elif p == "right":
@@ -178,93 +217,148 @@ class legacy:
 				r = int(float(r) / abs(p))
 			else:
 				l = int(float(l) / p)
-			
+
 			buf[i][0] = l
 			buf[i][1] = r
-		
-		self.sound = pygame.sndarray.make_sound(numpy.array(buf))											
-		
+
+		self.sound = pygame.sndarray.make_sound(numpy.array(buf))
+
 	def play(self, block = False):
-	
+
 		"""<DOC>
-		Play the sound
-		
+		Plays the sound.
+
 		Keyword arguments:
-		block -- If True, block until the sound is finished. (default == False)
+		block -- If True, block until the sound is finished (default = False).
+		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.play()
 		</DOC>"""
-	
-		self.sound.play(maxtime = self._stop_after, fade_ms = self._fade_in)		
+
+		self.sound.play(maxtime = self._stop_after, fade_ms = self._fade_in)
 		if block:
 			self.wait()
-						
+
 	def stop(self):
-	
+
 		"""<DOC>
-		Stops the currently playing sound (if any)
-		</DOC>"""
+		Stops the currently playing sound (if any).
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.play()
+		>>> self.sleep(100)
+		>>> my_sampler.stop()
+		</DOC>"""
+
 		pygame.mixer.stop()
-		
+
 	def pause(self):
-	
+
 		"""<DOC>
-		Pauses playback (if any)
-		</DOC>"""
+		Pauses playback (if any).
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.play()
+		>>> self.sleep(100)
+		>>> my_sampler.pause()				
+		>>> self.sleep(100)
+		>>> my_sampler.resume()				
+		</DOC>"""
+
 		pygame.mixer.pause()
-		
+
 	def resume(self):
-	
+
 		"""<DOC>
-		Resumes playback (if any)
-		</DOC>"""
+		Resumes playback (if any).
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.play()
+		>>> self.sleep(100)
+		>>> my_sampler.pause()				
+		>>> self.sleep(100)
+		>>> my_sampler.resume()				
+		</DOC>"""
+
 		pygame.mixer.unpause()
-		
+
 	def is_playing(self):
-	
+
 		"""<DOC>
-		Checks if a sound is currently playing
-		
+		Checks if a sound is currently playing.
+
 		Returns:
-		True if a sound is playing, False if not
+		True if a sound is playing, False if not.
+
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.play()
+		>>> self.sleep(100)
+		>>> if my_sampler.is_playing():
+		>>> 	print 'The sampler is still playing!'
 		</DOC>"""
-		
-		return pygame.mixer.get_busy()		
-		
+
+		return bool(pygame.mixer.get_busy())
+
 	def wait(self):
-	
+
 		"""<DOC>
-		Blocks until the sound has finished playing or
-		returns right away if no sound is playing
-		</DOC>"""
+		Blocks until the sound has finished playing or returns right away if no #
+		sound is playing.
 		
+		Example:
+		>>> from openexp.sampler import sampler
+		>>> src = exp.get_file('my_sound.ogg')
+		>>> my_sampler = sampler(exp, src)
+		>>> my_sampler.play()
+		>>> my_sampler.wait()
+		>>> print 'The sampler is finished!'
+		</DOC>"""
+
 		while pygame.mixer.get_busy():
 			pass
-	
+
 def init_sound(experiment):
 
 	"""
-	Initialize the pygame mixer before the experiment begins.
-	
+	Initializes the pygame mixer before the experiment begins.
+
 	Arguments:
 	experiment -- An instance of libopensesame.experiment.experiment
 	"""
-	
+
 	print "openexp.sampler._legacy.init_sound(): sampling freq = %d, buffer size = %d" \
-		% (experiment.sound_freq, experiment.sound_buf_size)		
+		% (experiment.sound_freq, experiment.sound_buf_size)
+	if pygame.mixer.get_init():
+		print 'openexp.sampler._legacy.init_sound(): mixer already initialized, closing'
+		pygame.mixer.quit()
 	pygame.mixer.pre_init(experiment.sound_freq, experiment.sound_sample_size, \
-		experiment.sound_channels, experiment.sound_buf_size)
+		experiment.sound_channels, experiment.sound_buf_size)	
+	pygame.mixer.init()
 
 
 def close_sound(experiment):
 
 	"""
-	Close the mixer after the experiment is finished.
-	
+	Closes the mixer after the experiment is finished.
+
 	Arguments:
-	experiment -- An instance of libopensesame.experiment.experiment	
+	experiment -- An instance of libopensesame.experiment.experiment
 	"""
-	
+
 	pygame.mixer.quit()
 
