@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of OpenSesame.
 
@@ -19,42 +21,53 @@ import sys
 import os.path
 
 legacy = {
-	"description" : "Default PyGame backend, a safe choice", \
+	"description" : "uses PyGame, maximum stability", \
 	"authors" : ["Sebastiaan Mathot"], \
 	"canvas" : "legacy", \
 	"keyboard" : "legacy", \
 	"mouse" : "legacy", \
 	"sampler" : "legacy", \
-	"synth" : "legacy" \
+	"synth" : "legacy", \
+	"icon" : "os-pygame"
 	}
 	
 opengl = {
-	"description" : "Uses PyGame in OpenGL mode", \
+	"description" : "uses PyGame and OpenGL", \
 	"authors" : ["Sebastiaan Mathot", "Per Sederberg"], \
 	"canvas" : "opengl", \
 	"keyboard" : "legacy", \
 	"mouse" : "legacy", \
 	"sampler" : "legacy", \
-	"synth" : "legacy" \
+	"synth" : "legacy", \
+	"icon" : "os-pygame"	
 	}	
 
 psycho = {
-	"description" : "Uses PsychoPy", \
+	"description" : "uses PsychoPy, powerful stimulus generation", \
 	"authors" : ["Sebastiaan Mathot", "Jonathan Peirce"], \
 	"canvas" : "psycho", \
 	"keyboard" : "psycho", \
 	"mouse" : "psycho", \
 	"sampler" : "legacy", \
-	"synth" : "legacy" \
+	"synth" : "legacy", \
+	"icon" : "os-psychopy"	
 	}
 	
+xpyriment = {
+	"description" : "uses Expyriment", \
+	"authors" : ["Sebastiaan Mathot"], \
+	"canvas" : "xpyriment", \
+	"keyboard" : "legacy", \
+	"mouse" : "xpyriment", \
+	"sampler" : "legacy", \
+	"synth" : "legacy", \
+	"icon" : "os-expyriment"
+	}	
+	
 backend_list = {}
 backend_list["legacy"] = legacy
-backend_list["opengl"] = opengl
-
-# So far, the psycho back-end doesn't work on Mac OS (darwin)
-if sys.platform != "darwin":
-	backend_list["psycho"] = psycho
+backend_list["xpyriment"] = xpyriment
+backend_list["psycho"] = psycho
 
 def match(experiment):
 
