@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of openexp.
 
@@ -15,6 +17,8 @@ You should have received a copy of the GNU General Public License
 along with openexp.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+from openexp import exceptions
+
 class sampler:
 
 	"""
@@ -33,7 +37,7 @@ class sampler:
 				exec("import openexp._sampler.%s" % experiment.sampler_backend)
 				self.__class__ = eval("openexp._sampler.%s.%s" % (experiment.sampler_backend, experiment.sampler_backend))
 			except Exception as e:
-				raise openexp.exceptions.sample_error("Failed to import 'openexp._sampler.%s' as sampler backend.<br /><br />Error: %s" % (experiment.sampler_backend, e))	
+				raise exceptions.sample_error("Failed to import 'openexp._sampler.%s' as sampler backend.<br /><br />Error: %s" % (experiment.sampler_backend, e))	
 											
 		exec("openexp._sampler.%s.%s.__init__(self, experiment, src)" % (experiment.sampler_backend, experiment.sampler_backend))				
 		
@@ -49,7 +53,7 @@ def init_sound(experiment):
 			exec("import openexp._sampler.%s" % experiment.sampler_backend)
 			exec("openexp._sampler.%s.init_sound(experiment)" % experiment.sampler_backend)
 		except Exception as e:
-			raise openexp.exceptions.sample_error("Failed to call openexp._sampler.%s.init_sound()<br /><br />Error: %s" % (experiment.sampler_backend, e))				
+			raise exceptions.sample_error("Failed to call openexp._sampler.%s.init_sound()<br /><br />Error: %s" % (experiment.sampler_backend, e))				
 
 def close_sound(experiment):
 
@@ -63,5 +67,5 @@ def close_sound(experiment):
 			exec("import openexp._sampler.%s" % experiment.sampler_backend)
 			exec("openexp._sampler.%s.close_sound(experiment)" % experiment.sampler_backend)
 		except Exception as e:
-			raise openexp.exceptions.sample_error("Failed to call openexp._sampler.%s.close_sound()<br /><br />Error: %s" % (experiment.sampler_backend, e))				
+			raise exceptions.sample_error("Failed to call openexp._sampler.%s.close_sound()<br /><br />Error: %s" % (experiment.sampler_backend, e))				
 
