@@ -15,7 +15,7 @@ You should have received a copy of the GNU General Public License
 along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from libopensesame import item, generic_response, exceptions
+from libopensesame import item, generic_response, exceptions, debug
 from libqtopensesame import qtplugin
 import openexp.keyboard
 import imp
@@ -31,11 +31,11 @@ class srbox(item.item, generic_response.generic_response):
 
 		"""
 		Constructor
-		
+
 		Arguments:
 		name -- item name
 		experiment -- opensesame experiment
-		
+
 		Keywords arguments:
 		string -- definition string (default=None)
 		"""
@@ -44,76 +44,81 @@ class srbox(item.item, generic_response.generic_response):
 		self.item_type = "srbox"
 
 		# Provide a short accurate description of the items functionality
-		self.description = "Collects input from a serial response box (Psychology Software Tools) or compatible devices"
+		self.description = \
+			"Collects input from a serial response box (Psychology Software Tools) or compatible devices"
 
 		# Set some item-specific variables
 		self.timeout = "infinite"
 		self.lights = ""
 		self.dev = "autodetect"
-		self.dummy = "no"		
+		self._dummy = "no"
+		self.process_feedback = True				
 
 		# The parent handles the rest of the contruction
 		item.item.__init__(self, name, experiment, string)
-		
+
 	def prepare(self):
 
 		"""
 		Prepare the item
-		
+
 		Returns:
-		True on success, False on failure		
+		True on success, False on failure
 		"""
 
 		# Pass the word on to the parent
 		item.item.prepare(self)
-				
+
 		# Prepare the allowed responses
 		if self.has("allowed_responses"):
 			self._allowed_responses = []
-			for r in str(self.get("allowed_responses")).split(";"):
+			for r in self.unistr(self.get("allowed_responses")).split(";"):
 				if r.strip() != "":
 					try:
 						r = int(r)
 					except:
-						raise exceptions.runtime_error("'%s' is not a valid response in srbox '%s'. Expecting a number in the range 0 .. 5." % (r, self.name))
+						raise exceptions.runtime_error( \
+							"'%s' is not a valid response in srbox '%s'. Expecting a number in the range 0 .. 5." \
+							% (r, self.name))
 					if r < 0 or r > 255:
-						raise exceptions.runtime_error("'%s' is not a valid response in srbox '%s'. Expecting a number in the range 0 .. 5." % (r, self.name))
+						raise exceptions.runtime_error( \
+							"'%s' is not a valid response in srbox '%s'. Expecting a number in the range 0 .. 5." \
+							% (r, self.name))
 					self._allowed_responses.append(r)
 			if len(self._allowed_responses) == 0:
 				self._allowed_responses = None
 		else:
 			self._allowed_responses = None
 
-		if self.experiment.debug:
-			print "srbox.prepare(): allowed responses set to %s" % self._allowed_responses
+		debug.msg("allowed responses set to %s" % self._allowed_responses)
 
 		self._keyboard = openexp.keyboard.keyboard(self.experiment)
-		if self.has("dummy") and self.get("dummy") == "yes":
+		if self.get('_dummy') == 'yes':
 			self._resp_func = self._keyboard.get_key
 
 		else:
-		
+
 			# Prepare the device string
 			dev = self.get("dev")
 			if dev == "autodetect":
 				dev = None
-		
+
 			# Dynamically load an srbox instance
-			if not hasattr(self.experiment, "srbox"):				
+			if not hasattr(self.experiment, "srbox"):
 				path = os.path.join(os.path.dirname(__file__), "libsrbox.py")
 				_srbox = imp.load_source("libsrbox", path)
 				self.experiment.srbox = _srbox.libsrbox(self.experiment, dev)
+				self.experiment.cleanup_functions.append(self.close)
 
 			# Prepare the light byte
 			s = "010" # Control string
 			for i in range(5):
-				if str(5 - i) in str(self.get("lights")):
+				if unicode(5 - i) in unicode(self.get("lights")):
 					s += "1"
 				else:
 					s += "0"
 			self._lights = chr(int(s, 2))
-			if self.experiment.debug:
-				print "srbox.prepare(): lights string set to %s (%s)" % (s, self.get("lights"))
+			debug.msg("lights string set to %s (%s)" % (s, self.get("lights")))
 
 			# Prepare auto response
 			if self.experiment.auto_response:
@@ -130,9 +135,9 @@ class srbox(item.item, generic_response.generic_response):
 
 		"""
 		Run the item
-		
+
 		Returns:
-		True on success, False on failure				
+		True on success, False on failure
 		"""
 
 		# Set the onset time
@@ -144,18 +149,22 @@ class srbox(item.item, generic_response.generic_response):
 		# If no start response interval has been set, set it to the onset of
 		# the current response item
 		if self.experiment.start_response_interval == None:
-			self.experiment.start_response_interval = self.get("time_%s" % self.name)
+			self.experiment.start_response_interval = self.get("time_%s" \
+				% self.name)
 
-		if self.has("dummy") and self.get("dummy") == "yes":
+		if self.get('_dummy') == 'yes':
 
-			# In dummy mode, we simply take the numeric keys from the keyboard instead of an sr-box
-			resp, self.experiment.end_response_interval = self._resp_func(None, self._timeout)
+			# In dummy mode, we simply take the numeric keys from the keyboard
+			resp, self.experiment.end_response_interval = self._resp_func( \
+				None, self._timeout)
 			try:
 				resp = self._keyboard.to_chr(resp)
 				if resp != "timeout":
 					resp = int(resp)
 			except:
-				raise exceptions.runtime_error("An error occured in srbox '%s': Only number keys are accepted in dummy mode" % self.name)
+				raise exceptions.runtime_error( \
+					"An error occured in srbox '%s': Only number keys are accepted in dummy mode" \
+					% self.name)
 
 		else:
 			# Get the response
@@ -166,23 +175,37 @@ class srbox(item.item, generic_response.generic_response):
 					self._resp_func(self._allowed_responses, self._timeout)
 				self.experiment.srbox.stop()
 			except Exception as e:
-				raise exceptions.runtime_error("An error occured in srbox '%s': %s." % (self.name, e))
+				raise exceptions.runtime_error( \
+					"An error occured in srbox '%s': %s." % (self.name, e))
 
-		if self.experiment.debug:
-			print "srbox.run(): received %s" % resp
+		debug.msg("received %s" % resp)
 		if type(resp) == list:
 			self.experiment.response = resp[0]
 		else:
 			self.experiment.response = resp
 
 		generic_response.generic_response.response_bookkeeping(self)
-			
+
 		# Report success
 		return True
-		
+
+	def close(self):
+
+		"""Neatly close the connection to the srbox"""
+
+		if not hasattr(self.experiment, "srbox") or \
+			self.experiment.srbox == None:
+				debug.msg("no active srbox")
+				return		
+		try:
+			self.experiment.srbox.close()
+			debug.msg("srbox closed")
+		except:
+			debug.msg("failed to close srbox")
+
 	def var_info(self):
 
-		return generic_response.generic_response.var_info(self)			
+		return generic_response.generic_response.var_info(self)
 
 class qtsrbox(srbox, qtplugin.qtplugin):
 
@@ -232,12 +255,20 @@ class qtsrbox(srbox, qtplugin.qtplugin):
 		# - creates a QLineEdit
 		# qtplugin.add_spinbox_control(varname, label, min, max, suffix = suffix, prefix = prefix)
 
-		self.add_combobox_control("dummy", "Dummy mode (use keyboard instead)", ["no", "yes"])
-		self.add_line_edit_control("dev", "Device name", tooltip = "Expecting a valid device name. Leave empty for autodetect.", default = "autodetect")
-		self.add_line_edit_control("correct_response", "Correct response", tooltip = "Expecting a button number (1 .. 5)")
-		self.add_line_edit_control("allowed_responses", "Allowed responses", tooltip = "Expecting a semicolon-separated list of button numbers, e.g., 1;3;4")
-		self.add_line_edit_control("timeout", "Timeout", tooltip = "Expecting a value in milliseconds or 'infinite'", default = "infinite")
-		self.add_line_edit_control("lights", "Turn on lights", tooltip = "Expecting a semicolon-separated list of light numbers, e.g., 1;3;4")
+		self.add_combobox_control("_dummy", \
+			"Dummy mode (use keyboard instead)", ["no", "yes"])
+		self.add_line_edit_control("dev", "Device name", tooltip= \
+			"Expecting a valid device name. Leave empty for autodetect.", \
+			default="autodetect")
+		self.add_line_edit_control("correct_response", "Correct response", \
+			tooltip="Expecting a button number (1 .. 5)")
+		self.add_line_edit_control("allowed_responses", "Allowed responses", \
+			tooltip="Expecting a semicolon-separated list of button numbers, e.g., 1;3;4")
+		self.add_line_edit_control("timeout", "Timeout", \
+			tooltip="Expecting a value in milliseconds or 'infinite'", default \
+			="infinite")
+		self.add_line_edit_control("lights", "Turn on lights", tooltip= \
+			"Expecting a semicolon-separated list of light numbers, e.g., 1;3;4")
 
 		# Add a stretch to the edit_vbox, so that the controls do not
 		# stretch to the bottom of the window.
