@@ -50,6 +50,7 @@ class text_input(item.item, generic_response.generic_response):
 		self.duration = "dummy"
 		self.accept_on = "return press"
 		self.timeout = 1000
+		self.process_feedback = True
 
 		# Provide a short accurate description of the items functionality
 		self.description = "Provides a simple text input"
@@ -71,12 +72,14 @@ class text_input(item.item, generic_response.generic_response):
 		# If no start response interval has been set, set it to the onset of
 		# the current response item
 		if self.experiment.start_response_interval == None:
-			self.experiment.start_response_interval = self.get("time_%s" % self.name)		
+			self.experiment.start_response_interval = self.get("time_%s" % \
+				self.name)
 
 		self._keyboard = openexp.keyboard.keyboard(self.experiment)
 
 		# Create a canvas
-		c = openexp.canvas.canvas(self.experiment, self.get("background"), self.get("foreground"))
+		c = openexp.canvas.canvas(self.experiment, self.get("background"), \
+			self.get("foreground"))
 		c.set_font(self.get("font_family"), self.get("font_size"))
 		c.set_penwidth(self.get("frame_width"))
 
@@ -86,21 +89,24 @@ class text_input(item.item, generic_response.generic_response):
 		maxchar = self.get("linewidth") / w
 
 		if maxchar < 2:
-			raise exceptions.runtime_error("The maximum line width is too small (or the font is too large) in text_input '%s'" % self.name)
+			raise exceptions.runtime_error( \
+				"The maximum line width is too small (or the font is too large) in text_input '%s'" \
+				% self.name)
 
 		margin = 32
 
-		question = self.experiment.unsanitize(self.eval_text(self.get("_question")))
+		question = self.eval_text(self.get("_question"))
 
 		resp = ""
 		response = ""
 		response_time = None
 		while True:
-		
+
 			if self._check_return and resp == "return":
 				break
-		
-			if self._check_timeout and self.time() - self.experiment.start_response_interval > self.timeout:
+
+			if self._check_timeout and self.time() - \
+				self.experiment.start_response_interval > self.timeout:
 				break
 
 			# Fill the canvas and put it to the screen
@@ -110,7 +116,9 @@ class text_input(item.item, generic_response.generic_response):
 			l = 0
 			for s in _s.split("\n"):
 				while len(s) > 0:
-					c.text(s[:maxchar], False, c.xcenter() - self.get("linewidth") / 2, c.ycenter() + h * l - self.get("linewidth") / 2)
+					c.text(s[:maxchar], False, c.xcenter() - \
+						self.get("linewidth") / 2, c.ycenter() + h * l - \
+						self.get("linewidth") / 2)
 					s = s[maxchar:]
 					l += 1
 				l += 1
@@ -125,43 +133,44 @@ class text_input(item.item, generic_response.generic_response):
 			c.show()
 
 			# Get the response and the moderators (shift etc.)
-			key, time = self._keyboard.get_key()
-			resp = self._keyboard.to_chr(key)
-			mods = self._keyboard.get_mods()
+			resp, time = self._keyboard.get_key()
+			if len(resp) == 1:
+				o = ord(resp)
+			else:
+				o = -1
 
 			if response_time == None:
 				response_time = time
 
 			# Process the response
-			if resp == "backspace":
+			if resp == "backspace" or o == 8:
 				if len(response) > 0:
 					response = response[:-1]
 			elif resp == "space":
 				response += " "
 			elif len(resp) == 1:
-				response += self._keyboard.shift(key, mods)
+				response += resp
 
-		self.experiment.set("response", self.experiment.usanitize(self.experiment.sanitize(response)))
-		self.experiment.end_response_interval = response_time		
+		self.experiment.set("response", self.experiment.sanitize(response))
+		self.experiment.end_response_interval = response_time
 		self.response_bookkeeping()
 
 		# Report success
 		return True
-		
+
 	def prepare(self):
-	
+
 		"""Prepare for the run phase"""
-		
+
+		item.item.prepare(self)
 		if self.get("accept_on") != "return press":
 			self._check_timeout = True
 		else:
 			self._check_timeout = False
-			
 		if self.get("accept_on") != "timeout":
 			self._check_return = True
 		else:
-			self._check_return = False			
-	
+			self._check_return = False
 		return True
 
 	def var_info(self):
@@ -198,6 +207,8 @@ class qttext_input(text_input, qtplugin.qtplugin):
 
 		# Pass the word on to the parent
 		qtplugin.qtplugin.init_edit_widget(self, False)
+		self.add_text( \
+			'<b>Deprecation warning:</b> Forms are faster and more flexible than the text_input plug-in')
 
 		# Create the controls
 		#
@@ -213,7 +224,6 @@ class qttext_input(text_input, qtplugin.qtplugin):
 		# - creates a QLineEdit
 		# qtplugin.add_spinbox_control(varname, label, min, max, suffix = suffix, prefix = prefix)
 
-		self.add_editor_control("_question", "Question", default = "Your question?", tooltip = "The question to be displayed above the input field")
 		self.add_spinbox_control("linewidth", "Maximum line width", 100, 2000, suffix = "px", tooltip = "The maximum width of the input field in pixels")
 		self.add_combobox_control("frame", "Draw frame", ["yes", "no"], tooltip = "If 'yes', a rectangular frame will be drawn around the input field")
 		self.add_spinbox_control("frame_width", "Frame width", 1, 512, suffix = "px", tooltip = "The width of the frame (if enabled)")
@@ -222,11 +232,8 @@ class qttext_input(text_input, qtplugin.qtplugin):
 		self.add_combobox_control("font_family", "Font family", ["mono", "sans", "serif"], tooltip = "The font style")
 		self.add_spinbox_control("font_size", "Font size", 1, 512, suffix = "pt", tooltip = "The font size")
 		self.add_combobox_control("accept_on", "Accept on", ["return press", "timeout", "return press or timeout"], tooltip = "Indicates when the input text should be accepted")
-		self.add_spinbox_control("timeout", "Timeout (if applicable)", 1, 100000, suffix = "ms", tooltip = "Timeout value")		
-
-		# Add a stretch to the edit_vbox, so that the controls do not
-		# stretch to the bottom of the window.
-		self.edit_vbox.addStretch()
+		self.add_spinbox_control("timeout", "Timeout (if applicable)", 1, 100000, suffix = "ms", tooltip = "Timeout value")
+		self.add_editor_control("_question", "Question", default = "Your question?", tooltip = "The question to be displayed above the input field")
 
 		self.lock = False
 
